@@ -79,7 +79,7 @@ class MemoryObject(MemoryReader):
         return await self.read_wide_string(base_address + offset, encoding)
 
     async def write_wide_string(
-        self, address: int, string: str, encoding: str = "utf-8"
+        self, address: int, string: str, encoding: str = "utf-16"
     ):
         string_len_addr = address + 16
         encoded = string.encode(encoding)
@@ -106,13 +106,14 @@ class MemoryObject(MemoryReader):
         else:
             await self.write_bytes(address, encoded + b"\x00")
 
-        await self.write_typed(string_len_addr, string_len, "int")
+        # take 2 bytes
+        await self.write_typed(string_len_addr, string_len // 2, "int")
 
     async def write_wide_string_to_offset(
-        self, offset: int, string: str, encoding: str = "utf-8"
+        self, offset: int, string: str, encoding: str = "utf-16"
     ):
         base_address = await self.read_base_address()
-        await self.write_string(base_address + offset, string, encoding)
+        await self.write_wide_string(base_address + offset, string, encoding)
 
     async def read_string(self, address: int, encoding: str = "utf-8") -> str:
         string_len = await self.read_typed(address + 16, "int")
@@ -276,30 +277,36 @@ class MemoryObject(MemoryReader):
 
         return pointers
 
-    async def read_shared_linked_list(self, offset: int) -> List[int]:
+    async def read_shared_linked_list(self, offset: int):
         list_addr = await self.read_value_from_offset(offset, "long long")
 
         addrs = []
-        next_node_addr = list_addr
+        # TODO: ensure this is always the case
+        # skip first node
+        next_node_addr = await self.read_typed(list_addr, "long long")
         list_size = await self.read_value_from_offset(offset + 8, "int")
-        for _ in range(list_size):
-            list_node = await self.read_typed(next_node_addr, "long long")
-            next_node_addr = await self.read_typed(list_node, "long long")
-            # pointer is +16 from "last" list node
-            addrs.append(await self.read_typed(list_node + 16, "long long"))
+
+        for i in range(list_size):
+            addr = await self.read_typed(next_node_addr + 16, "long long")
+            addrs.append(addr)
+            next_node_addr = await self.read_typed(next_node_addr, "long long")
 
         return addrs
 
     async def read_linked_list(self, offset: int) -> List[int]:
         list_addr = await self.read_value_from_offset(offset, "long long")
+        list_size = await self.read_value_from_offset(offset + 8, "int")
+
+        if list_size < 1:
+            return []
 
         addrs = []
-        next_node_addr = list_addr
-        list_size = await self.read_value_from_offset(offset + 8, "int")
-        for _ in range(list_size):
-            list_node = await self.read_typed(next_node_addr, "long long")
-            next_node_addr = await self.read_typed(list_node, "long long")
-            # object starts +16 from "last" list node
+        list_node = await self.read_typed(list_addr, "long long")
+        # object starts +16 from node
+        addrs.append(list_node + 16)
+        # -1 because we've already read one node
+        for _ in range(list_size - 1):
+            list_node = await self.read_typed(list_node, "long long")
             addrs.append(list_node + 16)
 
         return addrs
